#
#   wordtoexcel.py
#
#   Author  : Ahmed Obied (ahmed.obied@gmail.com)
#   Date    : 10/2009
#   Version : 0.1
#
#   WordToExcel is a tool to move data from tables in a Microsoft Word 
#   document to cells in a Microsoft Excel document. 
#
#   Usage: ./wordtoexcel.py [input file (word file)] [output file (excel file)]
#  

import sys
try:
    import win32com.client
except ImportError:
    print 'Error : the win32 extensions for Python are not installed'
    sys.exit(-1)
    
class WordDocument:
    
    def __init__(self, word_file):
        self.word = win32com.client.Dispatch('Word.Application')
        self.word.Visible = 0
        self.doc = self.word.Documents.Open(word_file)
        
    def tablesCount(self):
        return self.doc.Tables.Count
        
    def rowsCount(self, table):
        return self.doc.Tables(table).Rows.Count
        
    def columnsCount(self, table):
        return self.doc.Tables(table).Columns.Count
           
    def getText(self, table, row, column):
        return self.doc.Tables(table).Cell(row, column).Range.Text

    def closeDocument(self):
        self.doc.Close()
        self.word.Quit()
        
class ExcelDocument:
    
    def __init__(self, excel_file):
        self.excel = win32com.client.Dispatch('Excel.Application')
        self.excel.Visible = 0
        self.name = excel_file
        self.workbook = self.excel.Workbooks.Add()
        
    def addValue(self, row, column, value):
        self.workbook.Worksheets(1).Cells(row, column).Value = value
        
    def save(self):
        self.workbook.SaveAs(self.name)
        
    def closeDocument(self):
        self.excel.Quit() 
         
def process(w_file, e_file):
    print '[-] Input file (A Microsoft Word File)   : %s' % w_file 
    print '[-] Output file (A Microsoft Excel File) : %s' % e_file
    word_doc = None
    try:
        word_doc = WordDocument(w_file)
    except:
        print '[*] Error : an invalid input file was given'
        sys.exit(-1)
    print '[-] A total of %d were found in the input file' % word_doc.tablesCount()
    print '[-] Exporting the data in the tables to the output file ...'
    excel_doc = ExcelDocument(e_file)
    e_row = 1
    for t in range(1, word_doc.tablesCount() + 1):
        for r in range(2, word_doc.rowsCount(t) + 1):
            e_col = 1
            for c in range(1, word_doc.columnsCount(t) + 1):
                data = word_doc.getText(t, r, c)             
                data = data.strip('\x07')
                excel_doc.addValue(e_row, e_col, data)
                e_col += 1
            e_row += 1
    print '[-] All tables have been exported successfully'
    word_doc.closeDocument()
    excel_doc.save()
    excel_doc.closeDocument()
          
def main():
    if len(sys.argv[1:]) != 2:
        print 'Usage: %s [path to input file (word file)] [path to output file name (excel file)]' \
              % sys.argv[0] 
        sys.exit(0)
    print
    print '[************************************]'
    print '[   WordToExcel 0.1 by Ahmed Obied   ]'
    print '[************************************]'
    print 
    w_file = sys.argv[1]
    e_file = sys.argv[2]
    process(w_file, e_file)
       
if __name__ == '__main__':
    main()
    